@@ -118,11 +118,13 @@ class GraphShow():
                 data_css= folder + "/data/vis.css"
        
         elif platform.system() == "Windows":
-            data_js = join(sys.prefix , "data_VIS\vis.js")
-            data_css = join(sys.prefix , "data_VIS\vis.css")
+            data_js = join(sys.prefix , "data_VIS\\vis.js")
+            data_js = "file:///" + data_js
+            data_css = join(sys.prefix , "data_VIS\\vis.css")
+            data_css = "file:///" + data_css
             if not os.path.isfile(data_js):
                 graph_show_path = os.path.abspath(__file__)
-                folder = "\".join(graph_show_path.split("\")[:-2])
+                folder = "\\".join(graph_show_path.split("\\")[:-2])
         
         else:
             data_js = join(sys.prefix , 'data_VIS/vis.js')
